@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,10 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
 from google.analytics.data_v1beta.types import data
 
 
@@ -53,18 +50,15 @@ class Metadata(proto.Message):
             The metric descriptions.
     """
 
-    name = proto.Field(proto.STRING, number=3)
-
+    name = proto.Field(proto.STRING, number=3,)
     dimensions = proto.RepeatedField(
         proto.MESSAGE, number=1, message=data.DimensionMetadata,
     )
-
     metrics = proto.RepeatedField(proto.MESSAGE, number=2, message=data.MetricMetadata,)
 
 
 class RunReportRequest(proto.Message):
     r"""The request to generate a report.
-
     Attributes:
         property (str):
             A Google Analytics GA4 property identifier whose events are
@@ -149,42 +143,28 @@ class RunReportRequest(proto.Message):
             `PropertyQuota <#PropertyQuota>`__.
     """
 
-    property = proto.Field(proto.STRING, number=1)
-
+    property = proto.Field(proto.STRING, number=1,)
     dimensions = proto.RepeatedField(proto.MESSAGE, number=2, message=data.Dimension,)
-
     metrics = proto.RepeatedField(proto.MESSAGE, number=3, message=data.Metric,)
-
     date_ranges = proto.RepeatedField(proto.MESSAGE, number=4, message=data.DateRange,)
-
     dimension_filter = proto.Field(
         proto.MESSAGE, number=5, message=data.FilterExpression,
     )
-
     metric_filter = proto.Field(proto.MESSAGE, number=6, message=data.FilterExpression,)
-
-    offset = proto.Field(proto.INT64, number=7)
-
-    limit = proto.Field(proto.INT64, number=8)
-
+    offset = proto.Field(proto.INT64, number=7,)
+    limit = proto.Field(proto.INT64, number=8,)
     metric_aggregations = proto.RepeatedField(
         proto.ENUM, number=9, enum=data.MetricAggregation,
     )
-
     order_bys = proto.RepeatedField(proto.MESSAGE, number=10, message=data.OrderBy,)
-
-    currency_code = proto.Field(proto.STRING, number=11)
-
+    currency_code = proto.Field(proto.STRING, number=11,)
     cohort_spec = proto.Field(proto.MESSAGE, number=12, message=data.CohortSpec,)
-
-    keep_empty_rows = proto.Field(proto.BOOL, number=13)
-
-    return_property_quota = proto.Field(proto.BOOL, number=14)
+    keep_empty_rows = proto.Field(proto.BOOL, number=13,)
+    return_property_quota = proto.Field(proto.BOOL, number=14,)
 
 
 class RunReportResponse(proto.Message):
     r"""The response report table corresponding to a request.
-
     Attributes:
         dimension_headers (Sequence[google.analytics.data_v1beta.types.DimensionHeader]):
             Describes dimension columns. The number of
@@ -220,34 +200,31 @@ class RunReportResponse(proto.Message):
         property_quota (google.analytics.data_v1beta.types.PropertyQuota):
             This Analytics Property's quota state
             including this request.
+        kind (str):
+            Identifies what kind of resource this message is. This
+            ``kind`` is always the fixed string
+            "analyticsData#runReport". Useful to distinguish between
+            response types in JSON.
     """
 
     dimension_headers = proto.RepeatedField(
         proto.MESSAGE, number=1, message=data.DimensionHeader,
     )
-
     metric_headers = proto.RepeatedField(
         proto.MESSAGE, number=2, message=data.MetricHeader,
     )
-
     rows = proto.RepeatedField(proto.MESSAGE, number=3, message=data.Row,)
-
     totals = proto.RepeatedField(proto.MESSAGE, number=4, message=data.Row,)
-
     maximums = proto.RepeatedField(proto.MESSAGE, number=5, message=data.Row,)
-
     minimums = proto.RepeatedField(proto.MESSAGE, number=6, message=data.Row,)
-
-    row_count = proto.Field(proto.INT32, number=7)
-
+    row_count = proto.Field(proto.INT32, number=7,)
     metadata = proto.Field(proto.MESSAGE, number=8, message=data.ResponseMetaData,)
-
     property_quota = proto.Field(proto.MESSAGE, number=9, message=data.PropertyQuota,)
+    kind = proto.Field(proto.STRING, number=10,)
 
 
 class RunPivotReportRequest(proto.Message):
     r"""The request to generate a pivot report.
-
     Attributes:
         property (str):
             A Google Analytics GA4 property identifier whose events are
@@ -311,29 +288,19 @@ class RunPivotReportRequest(proto.Message):
             `PropertyQuota <#PropertyQuota>`__.
     """
 
-    property = proto.Field(proto.STRING, number=1)
-
+    property = proto.Field(proto.STRING, number=1,)
     dimensions = proto.RepeatedField(proto.MESSAGE, number=2, message=data.Dimension,)
-
     metrics = proto.RepeatedField(proto.MESSAGE, number=3, message=data.Metric,)
-
     date_ranges = proto.RepeatedField(proto.MESSAGE, number=4, message=data.DateRange,)
-
     pivots = proto.RepeatedField(proto.MESSAGE, number=5, message=data.Pivot,)
-
     dimension_filter = proto.Field(
         proto.MESSAGE, number=6, message=data.FilterExpression,
     )
-
     metric_filter = proto.Field(proto.MESSAGE, number=7, message=data.FilterExpression,)
-
-    currency_code = proto.Field(proto.STRING, number=8)
-
+    currency_code = proto.Field(proto.STRING, number=8,)
     cohort_spec = proto.Field(proto.MESSAGE, number=9, message=data.CohortSpec,)
-
-    keep_empty_rows = proto.Field(proto.BOOL, number=10)
-
-    return_property_quota = proto.Field(proto.BOOL, number=11)
+    keep_empty_rows = proto.Field(proto.BOOL, number=10,)
+    return_property_quota = proto.Field(proto.BOOL, number=11,)
 
 
 class RunPivotReportResponse(proto.Message):
@@ -405,32 +372,31 @@ class RunPivotReportResponse(proto.Message):
         property_quota (google.analytics.data_v1beta.types.PropertyQuota):
             This Analytics Property's quota state
             including this request.
+        kind (str):
+            Identifies what kind of resource this message is. This
+            ``kind`` is always the fixed string
+            "analyticsData#runPivotReport". Useful to distinguish
+            between response types in JSON.
     """
 
     pivot_headers = proto.RepeatedField(
         proto.MESSAGE, number=1, message=data.PivotHeader,
     )
-
     dimension_headers = proto.RepeatedField(
         proto.MESSAGE, number=2, message=data.DimensionHeader,
     )
-
     metric_headers = proto.RepeatedField(
         proto.MESSAGE, number=3, message=data.MetricHeader,
     )
-
     rows = proto.RepeatedField(proto.MESSAGE, number=4, message=data.Row,)
-
     aggregates = proto.RepeatedField(proto.MESSAGE, number=5, message=data.Row,)
-
     metadata = proto.Field(proto.MESSAGE, number=6, message=data.ResponseMetaData,)
-
     property_quota = proto.Field(proto.MESSAGE, number=7, message=data.PropertyQuota,)
+    kind = proto.Field(proto.STRING, number=8,)
 
 
 class BatchRunReportsRequest(proto.Message):
     r"""The batch request containing multiple report requests.
-
     Attributes:
         property (str):
             A Google Analytics GA4 property identifier whose events are
@@ -448,26 +414,29 @@ class BatchRunReportsRequest(proto.Message):
             allowed up to 5 requests.
     """
 
-    property = proto.Field(proto.STRING, number=1)
-
+    property = proto.Field(proto.STRING, number=1,)
     requests = proto.RepeatedField(proto.MESSAGE, number=2, message="RunReportRequest",)
 
 
 class BatchRunReportsResponse(proto.Message):
     r"""The batch response containing multiple reports.
-
     Attributes:
         reports (Sequence[google.analytics.data_v1beta.types.RunReportResponse]):
             Individual responses. Each response has a
             separate report request.
+        kind (str):
+            Identifies what kind of resource this message is. This
+            ``kind`` is always the fixed string
+            "analyticsData#batchRunReports". Useful to distinguish
+            between response types in JSON.
     """
 
     reports = proto.RepeatedField(proto.MESSAGE, number=1, message="RunReportResponse",)
+    kind = proto.Field(proto.STRING, number=2,)
 
 
 class BatchRunPivotReportsRequest(proto.Message):
     r"""The batch request containing multiple pivot report requests.
-
     Attributes:
         property (str):
             A Google Analytics GA4 property identifier whose events are
@@ -485,8 +454,7 @@ class BatchRunPivotReportsRequest(proto.Message):
             request is allowed up to 5 requests.
     """
 
-    property = proto.Field(proto.STRING, number=1)
-
+    property = proto.Field(proto.STRING, number=1,)
     requests = proto.RepeatedField(
         proto.MESSAGE, number=2, message="RunPivotReportRequest",
     )
@@ -494,21 +462,25 @@ class BatchRunPivotReportsRequest(proto.Message):
 
 class BatchRunPivotReportsResponse(proto.Message):
     r"""The batch response containing multiple pivot reports.
-
     Attributes:
         pivot_reports (Sequence[google.analytics.data_v1beta.types.RunPivotReportResponse]):
             Individual responses. Each response has a
             separate pivot report request.
+        kind (str):
+            Identifies what kind of resource this message is. This
+            ``kind`` is always the fixed string
+            "analyticsData#batchRunPivotReports". Useful to distinguish
+            between response types in JSON.
     """
 
     pivot_reports = proto.RepeatedField(
         proto.MESSAGE, number=1, message="RunPivotReportResponse",
     )
+    kind = proto.Field(proto.STRING, number=2,)
 
 
 class GetMetadataRequest(proto.Message):
     r"""Request for a property's dimension and metric metadata.
-
     Attributes:
         name (str):
             Required. The resource name of the metadata to retrieve.
@@ -525,12 +497,11 @@ class GetMetadataRequest(proto.Message):
             not return custom dimensions and metrics.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class RunRealtimeReportRequest(proto.Message):
     r"""The request to generate a realtime report.
-
     Attributes:
         property (str):
             A Google Analytics GA4 property identifier whose events are
@@ -576,29 +547,33 @@ class RunRealtimeReportRequest(proto.Message):
             Toggles whether to return the current state of this
             Analytics Property's Realtime quota. Quota is returned in
             `PropertyQuota <#PropertyQuota>`__.
+        minute_ranges (Sequence[google.analytics.data_v1beta.types.MinuteRange]):
+            The minute ranges of event data to read. If
+            unspecified, one minute range for the last 30
+            minutes will be used. If multiple minute ranges
+            are requested, each response row will contain a
+            zero based minute range index. If two minute
+            ranges overlap, the event data for the
+            overlapping minutes is included in the response
+            rows for both minute ranges.
     """
 
-    property = proto.Field(proto.STRING, number=1)
-
+    property = proto.Field(proto.STRING, number=1,)
     dimensions = proto.RepeatedField(proto.MESSAGE, number=2, message=data.Dimension,)
-
     metrics = proto.RepeatedField(proto.MESSAGE, number=3, message=data.Metric,)
-
     dimension_filter = proto.Field(
         proto.MESSAGE, number=4, message=data.FilterExpression,
     )
-
     metric_filter = proto.Field(proto.MESSAGE, number=5, message=data.FilterExpression,)
-
-    limit = proto.Field(proto.INT64, number=6)
-
+    limit = proto.Field(proto.INT64, number=6,)
     metric_aggregations = proto.RepeatedField(
         proto.ENUM, number=7, enum=data.MetricAggregation,
     )
-
     order_bys = proto.RepeatedField(proto.MESSAGE, number=8, message=data.OrderBy,)
-
-    return_property_quota = proto.Field(proto.BOOL, number=9)
+    return_property_quota = proto.Field(proto.BOOL, number=9,)
+    minute_ranges = proto.RepeatedField(
+        proto.MESSAGE, number=10, message=data.MinuteRange,
+    )
 
 
 class RunRealtimeReportResponse(proto.Message):
@@ -634,27 +609,26 @@ class RunRealtimeReportResponse(proto.Message):
         property_quota (google.analytics.data_v1beta.types.PropertyQuota):
             This Analytics Property's Realtime quota
             state including this request.
+        kind (str):
+            Identifies what kind of resource this message is. This
+            ``kind`` is always the fixed string
+            "analyticsData#runRealtimeReport". Useful to distinguish
+            between response types in JSON.
     """
 
     dimension_headers = proto.RepeatedField(
         proto.MESSAGE, number=1, message=data.DimensionHeader,
     )
-
     metric_headers = proto.RepeatedField(
         proto.MESSAGE, number=2, message=data.MetricHeader,
     )
-
     rows = proto.RepeatedField(proto.MESSAGE, number=3, message=data.Row,)
-
     totals = proto.RepeatedField(proto.MESSAGE, number=4, message=data.Row,)
-
     maximums = proto.RepeatedField(proto.MESSAGE, number=5, message=data.Row,)
-
     minimums = proto.RepeatedField(proto.MESSAGE, number=6, message=data.Row,)
-
-    row_count = proto.Field(proto.INT32, number=7)
-
+    row_count = proto.Field(proto.INT32, number=7,)
     property_quota = proto.Field(proto.MESSAGE, number=8, message=data.PropertyQuota,)
+    kind = proto.Field(proto.STRING, number=9,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
