@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
 
@@ -24,6 +22,7 @@ __protobuf__ = proto.module(
         "MetricAggregation",
         "MetricType",
         "DateRange",
+        "MinuteRange",
         "Dimension",
         "DimensionExpression",
         "Metric",
@@ -104,11 +103,51 @@ class DateRange(proto.Message):
             in the request: ``date_range_0``, ``date_range_1``, etc.
     """
 
-    start_date = proto.Field(proto.STRING, number=1)
+    start_date = proto.Field(proto.STRING, number=1,)
+    end_date = proto.Field(proto.STRING, number=2,)
+    name = proto.Field(proto.STRING, number=3,)
 
-    end_date = proto.Field(proto.STRING, number=2)
 
-    name = proto.Field(proto.STRING, number=3)
+class MinuteRange(proto.Message):
+    r"""A contiguous set of minutes: startMinutesAgo, startMinutesAgo
+    + 1, ..., endMinutesAgo. Requests are allowed up to 2 minute
+    ranges.
+
+    Attributes:
+        start_minutes_ago (int):
+            The inclusive start minute for the query as a number of
+            minutes before now. For example, ``"startMinutesAgo": 29``
+            specifies the report should include event data from 29
+            minutes ago and after. Cannot be after ``endMinutesAgo``.
+
+            If unspecified, ``startMinutesAgo`` is defaulted to 29.
+            Standard Analytics properties can request up to the last 30
+            minutes of event data (``startMinutesAgo <= 29``), and 360
+            Analytics properties can request up to the last 60 minutes
+            of event data (``startMinutesAgo <= 59``).
+        end_minutes_ago (int):
+            The inclusive end minute for the query as a number of
+            minutes before now. Cannot be before ``startMinutesAgo``.
+            For example, ``"endMinutesAgo": 15`` specifies the report
+            should include event data from prior to 15 minutes ago.
+
+            If unspecified, ``endMinutesAgo`` is defaulted to 0.
+            Standard Analytics properties can request any minute in the
+            last 30 minutes of event data (``endMinutesAgo <= 29``), and
+            360 Analytics properties can request any minute in the last
+            60 minutes of event data (``endMinutesAgo <= 59``).
+        name (str):
+            Assigns a name to this minute range. The dimension
+            ``dateRange`` is valued to this name in a report response.
+            If set, cannot begin with ``date_range_`` or ``RESERVED_``.
+            If not set, minute ranges are named by their zero based
+            index in the request: ``date_range_0``, ``date_range_1``,
+            etc.
+    """
+
+    start_minutes_ago = proto.Field(proto.INT32, number=1, optional=True,)
+    end_minutes_ago = proto.Field(proto.INT32, number=2, optional=True,)
+    name = proto.Field(proto.STRING, number=3,)
 
 
 class Dimension(proto.Message):
@@ -116,7 +155,7 @@ class Dimension(proto.Message):
     dimension city indicates the city from which an event
     originates. Dimension values in report responses are strings;
     for example, city could be "Paris" or "New York". Requests are
-    allowed up to 8 dimensions.
+    allowed up to 9 dimensions.
 
     Attributes:
         name (str):
@@ -141,8 +180,7 @@ class Dimension(proto.Message):
             ", ", city).
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
+    name = proto.Field(proto.STRING, number=1,)
     dimension_expression = proto.Field(
         proto.MESSAGE, number=2, message="DimensionExpression",
     )
@@ -170,18 +208,16 @@ class DimensionExpression(proto.Message):
 
     class CaseExpression(proto.Message):
         r"""Used to convert a dimension value to a single case.
-
         Attributes:
             dimension_name (str):
                 Name of a dimension. The name must refer back
                 to a name in dimensions field of the request.
         """
 
-        dimension_name = proto.Field(proto.STRING, number=1)
+        dimension_name = proto.Field(proto.STRING, number=1,)
 
     class ConcatenateExpression(proto.Message):
         r"""Used to combine dimension values to a single dimension.
-
         Attributes:
             dimension_names (Sequence[str]):
                 Names of dimensions. The names must refer
@@ -198,18 +234,15 @@ class DimensionExpression(proto.Message):
                 response will contain "US,FR,JP".
         """
 
-        dimension_names = proto.RepeatedField(proto.STRING, number=1)
-
-        delimiter = proto.Field(proto.STRING, number=2)
+        dimension_names = proto.RepeatedField(proto.STRING, number=1,)
+        delimiter = proto.Field(proto.STRING, number=2,)
 
     lower_case = proto.Field(
         proto.MESSAGE, number=4, oneof="one_expression", message=CaseExpression,
     )
-
     upper_case = proto.Field(
         proto.MESSAGE, number=5, oneof="one_expression", message=CaseExpression,
     )
-
     concatenate = proto.Field(
         proto.MESSAGE, number=6, oneof="one_expression", message=ConcatenateExpression,
     )
@@ -246,11 +279,9 @@ class Metric(proto.Message):
             ``orderBys``, or a metric ``expression``.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    expression = proto.Field(proto.STRING, number=2)
-
-    invisible = proto.Field(proto.BOOL, number=3)
+    name = proto.Field(proto.STRING, number=1,)
+    expression = proto.Field(proto.STRING, number=2,)
+    invisible = proto.Field(proto.BOOL, number=3,)
 
 
 class FilterExpression(proto.Message):
@@ -274,21 +305,17 @@ class FilterExpression(proto.Message):
     and_group = proto.Field(
         proto.MESSAGE, number=1, oneof="expr", message="FilterExpressionList",
     )
-
     or_group = proto.Field(
         proto.MESSAGE, number=2, oneof="expr", message="FilterExpressionList",
     )
-
     not_expression = proto.Field(
         proto.MESSAGE, number=3, oneof="expr", message="FilterExpression",
     )
-
     filter = proto.Field(proto.MESSAGE, number=4, oneof="expr", message="Filter",)
 
 
 class FilterExpressionList(proto.Message):
     r"""A list of filter expressions.
-
     Attributes:
         expressions (Sequence[google.analytics.data_v1beta.types.FilterExpression]):
             A list of filter expressions.
@@ -301,7 +328,6 @@ class FilterExpressionList(proto.Message):
 
 class Filter(proto.Message):
     r"""An expression to filter dimension or metric values.
-
     Attributes:
         field_name (str):
             The dimension name or metric name. Must be a
@@ -318,7 +344,6 @@ class Filter(proto.Message):
 
     class StringFilter(proto.Message):
         r"""The filter for string
-
         Attributes:
             match_type (google.analytics.data_v1beta.types.Filter.StringFilter.MatchType):
                 The match type for this filter.
@@ -341,14 +366,11 @@ class Filter(proto.Message):
         match_type = proto.Field(
             proto.ENUM, number=1, enum="Filter.StringFilter.MatchType",
         )
-
-        value = proto.Field(proto.STRING, number=2)
-
-        case_sensitive = proto.Field(proto.BOOL, number=3)
+        value = proto.Field(proto.STRING, number=2,)
+        case_sensitive = proto.Field(proto.BOOL, number=3,)
 
     class InListFilter(proto.Message):
         r"""The result needs to be in a list of string values.
-
         Attributes:
             values (Sequence[str]):
                 The list of string values.
@@ -357,13 +379,11 @@ class Filter(proto.Message):
                 If true, the string value is case sensitive.
         """
 
-        values = proto.RepeatedField(proto.STRING, number=1)
-
-        case_sensitive = proto.Field(proto.BOOL, number=2)
+        values = proto.RepeatedField(proto.STRING, number=1,)
+        case_sensitive = proto.Field(proto.BOOL, number=2,)
 
     class NumericFilter(proto.Message):
         r"""Filters for numeric or date values.
-
         Attributes:
             operation (google.analytics.data_v1beta.types.Filter.NumericFilter.Operation):
                 The operation type for this filter.
@@ -383,7 +403,6 @@ class Filter(proto.Message):
         operation = proto.Field(
             proto.ENUM, number=1, enum="Filter.NumericFilter.Operation",
         )
-
         value = proto.Field(proto.MESSAGE, number=2, message="NumericValue",)
 
     class BetweenFilter(proto.Message):
@@ -398,23 +417,18 @@ class Filter(proto.Message):
         """
 
         from_value = proto.Field(proto.MESSAGE, number=1, message="NumericValue",)
-
         to_value = proto.Field(proto.MESSAGE, number=2, message="NumericValue",)
 
-    field_name = proto.Field(proto.STRING, number=1)
-
+    field_name = proto.Field(proto.STRING, number=1,)
     string_filter = proto.Field(
         proto.MESSAGE, number=3, oneof="one_filter", message=StringFilter,
     )
-
     in_list_filter = proto.Field(
         proto.MESSAGE, number=4, oneof="one_filter", message=InListFilter,
     )
-
     numeric_filter = proto.Field(
         proto.MESSAGE, number=5, oneof="one_filter", message=NumericFilter,
     )
-
     between_filter = proto.Field(
         proto.MESSAGE, number=6, oneof="one_filter", message=BetweenFilter,
     )
@@ -422,7 +436,6 @@ class Filter(proto.Message):
 
 class OrderBy(proto.Message):
     r"""The sort options.
-
     Attributes:
         metric (google.analytics.data_v1beta.types.OrderBy.MetricOrderBy):
             Sorts results by a metric's values.
@@ -437,17 +450,15 @@ class OrderBy(proto.Message):
 
     class MetricOrderBy(proto.Message):
         r"""Sorts by metric values.
-
         Attributes:
             metric_name (str):
                 A metric name in the request to order by.
         """
 
-        metric_name = proto.Field(proto.STRING, number=1)
+        metric_name = proto.Field(proto.STRING, number=1,)
 
     class DimensionOrderBy(proto.Message):
         r"""Sorts by dimension values.
-
         Attributes:
             dimension_name (str):
                 A dimension name in the request to order by.
@@ -463,15 +474,13 @@ class OrderBy(proto.Message):
             CASE_INSENSITIVE_ALPHANUMERIC = 2
             NUMERIC = 3
 
-        dimension_name = proto.Field(proto.STRING, number=1)
-
+        dimension_name = proto.Field(proto.STRING, number=1,)
         order_type = proto.Field(
             proto.ENUM, number=2, enum="OrderBy.DimensionOrderBy.OrderType",
         )
 
     class PivotOrderBy(proto.Message):
         r"""Sorts by a pivot column group.
-
         Attributes:
             metric_name (str):
                 In the response to order by, order rows by
@@ -513,12 +522,10 @@ class OrderBy(proto.Message):
                     this value.
             """
 
-            dimension_name = proto.Field(proto.STRING, number=1)
-
-            dimension_value = proto.Field(proto.STRING, number=2)
-
-        metric_name = proto.Field(proto.STRING, number=1)
+            dimension_name = proto.Field(proto.STRING, number=1,)
+            dimension_value = proto.Field(proto.STRING, number=2,)
 
+        metric_name = proto.Field(proto.STRING, number=1,)
         pivot_selections = proto.RepeatedField(
             proto.MESSAGE, number=2, message="OrderBy.PivotOrderBy.PivotSelection",
         )
@@ -526,16 +533,13 @@ class OrderBy(proto.Message):
     metric = proto.Field(
         proto.MESSAGE, number=1, oneof="one_order_by", message=MetricOrderBy,
     )
-
     dimension = proto.Field(
         proto.MESSAGE, number=2, oneof="one_order_by", message=DimensionOrderBy,
     )
-
     pivot = proto.Field(
         proto.MESSAGE, number=3, oneof="one_order_by", message=PivotOrderBy,
     )
-
-    desc = proto.Field(proto.BOOL, number=4)
+    desc = proto.Field(proto.BOOL, number=4,)
 
 
 class Pivot(proto.Message):
@@ -562,9 +566,8 @@ class Pivot(proto.Message):
             is counted as row 0.
         limit (int):
             The number of unique combinations of dimension values to
-            return in this pivot. If unspecified, up to 10,000 unique
-            combinations of dimension values are returned. ``limit``
-            must be positive.
+            return in this pivot. The ``limit`` parameter is required. A
+            ``limit`` of 10,000 is common for single pivot requests.
 
             The product of the ``limit`` for each ``pivot`` in a
             ``RunPivotReportRequest`` must not exceed 100,000. For
@@ -575,14 +578,10 @@ class Pivot(proto.Message):
             specified metric_aggregations.
     """
 
-    field_names = proto.RepeatedField(proto.STRING, number=1)
-
+    field_names = proto.RepeatedField(proto.STRING, number=1,)
     order_bys = proto.RepeatedField(proto.MESSAGE, number=2, message="OrderBy",)
-
-    offset = proto.Field(proto.INT64, number=3)
-
-    limit = proto.Field(proto.INT64, number=4)
-
+    offset = proto.Field(proto.INT64, number=3,)
+    limit = proto.Field(proto.INT64, number=4,)
     metric_aggregations = proto.RepeatedField(
         proto.ENUM, number=5, enum="MetricAggregation",
     )
@@ -625,9 +624,7 @@ class CohortSpec(proto.Message):
     """
 
     cohorts = proto.RepeatedField(proto.MESSAGE, number=1, message="Cohort",)
-
     cohorts_range = proto.Field(proto.MESSAGE, number=2, message="CohortsRange",)
-
     cohort_report_settings = proto.Field(
         proto.MESSAGE, number=3, message="CohortReportSettings",
     )
@@ -672,10 +669,8 @@ class Cohort(proto.Message):
             month.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    dimension = proto.Field(proto.STRING, number=2)
-
+    name = proto.Field(proto.STRING, number=1,)
+    dimension = proto.Field(proto.STRING, number=2,)
     date_range = proto.Field(proto.MESSAGE, number=3, message="DateRange",)
 
 
@@ -736,22 +731,19 @@ class CohortsRange(proto.Message):
         MONTHLY = 3
 
     granularity = proto.Field(proto.ENUM, number=1, enum=Granularity,)
-
-    start_offset = proto.Field(proto.INT32, number=2)
-
-    end_offset = proto.Field(proto.INT32, number=3)
+    start_offset = proto.Field(proto.INT32, number=2,)
+    end_offset = proto.Field(proto.INT32, number=3,)
 
 
 class CohortReportSettings(proto.Message):
     r"""Optional settings of a cohort report.
-
     Attributes:
         accumulate (bool):
             If true, accumulates the result from first touch day to the
             end day. Not supported in ``RunReportRequest``.
     """
 
-    accumulate = proto.Field(proto.BOOL, number=1)
+    accumulate = proto.Field(proto.BOOL, number=1,)
 
 
 class ResponseMetaData(proto.Message):
@@ -765,7 +757,7 @@ class ResponseMetaData(proto.Message):
             can happen for high cardinality reports.
     """
 
-    data_loss_from_other_row = proto.Field(proto.BOOL, number=3)
+    data_loss_from_other_row = proto.Field(proto.BOOL, number=3,)
 
 
 class DimensionHeader(proto.Message):
@@ -780,7 +772,7 @@ class DimensionHeader(proto.Message):
             The dimension's name.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class MetricHeader(proto.Message):
@@ -797,14 +789,12 @@ class MetricHeader(proto.Message):
             The metric's data type.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
+    name = proto.Field(proto.STRING, number=1,)
     type_ = proto.Field(proto.ENUM, number=2, enum="MetricType",)
 
 
 class PivotHeader(proto.Message):
     r"""Dimensions' values in a single pivot.
-
     Attributes:
         pivot_dimension_headers (Sequence[google.analytics.data_v1beta.types.PivotDimensionHeader]):
             The size is the same as the cardinality of
@@ -818,13 +808,11 @@ class PivotHeader(proto.Message):
     pivot_dimension_headers = proto.RepeatedField(
         proto.MESSAGE, number=1, message="PivotDimensionHeader",
     )
-
-    row_count = proto.Field(proto.INT32, number=2)
+    row_count = proto.Field(proto.INT32, number=2,)
 
 
 class PivotDimensionHeader(proto.Message):
     r"""Summarizes dimension values from a row for this pivot.
-
     Attributes:
         dimension_values (Sequence[google.analytics.data_v1beta.types.DimensionValue]):
             Values of multiple dimensions in a pivot.
@@ -885,36 +873,32 @@ class Row(proto.Message):
     dimension_values = proto.RepeatedField(
         proto.MESSAGE, number=1, message="DimensionValue",
     )
-
     metric_values = proto.RepeatedField(proto.MESSAGE, number=2, message="MetricValue",)
 
 
 class DimensionValue(proto.Message):
     r"""The value of a dimension.
-
     Attributes:
         value (str):
             Value as a string if the dimension type is a
             string.
     """
 
-    value = proto.Field(proto.STRING, number=1, oneof="one_value")
+    value = proto.Field(proto.STRING, number=1, oneof="one_value",)
 
 
 class MetricValue(proto.Message):
     r"""The value of a metric.
-
     Attributes:
         value (str):
             Measurement value. See MetricHeader for type.
     """
 
-    value = proto.Field(proto.STRING, number=4, oneof="one_value")
+    value = proto.Field(proto.STRING, number=4, oneof="one_value",)
 
 
 class NumericValue(proto.Message):
     r"""To represent a number.
-
     Attributes:
         int64_value (int):
             Integer value
@@ -922,9 +906,8 @@ class NumericValue(proto.Message):
             Double value
     """
 
-    int64_value = proto.Field(proto.INT64, number=1, oneof="one_value")
-
-    double_value = proto.Field(proto.DOUBLE, number=2, oneof="one_value")
+    int64_value = proto.Field(proto.INT64, number=1, oneof="one_value",)
+    double_value = proto.Field(proto.DOUBLE, number=2, oneof="one_value",)
 
 
 class PropertyQuota(proto.Message):
@@ -955,22 +938,28 @@ class PropertyQuota(proto.Message):
             per hour; Analytics 360 Properties and cloud
             project pairs can have up to 50 server errors
             per hour.
+        potentially_thresholded_requests_per_hour (google.analytics.data_v1beta.types.QuotaStatus):
+            Analytics Properties can send up to 120
+            requests with potentially thresholded dimensions
+            per hour. In a batch request, each report
+            request is individually counted for this quota
+            if the request contains potentially thresholded
+            dimensions.
     """
 
     tokens_per_day = proto.Field(proto.MESSAGE, number=1, message="QuotaStatus",)
-
     tokens_per_hour = proto.Field(proto.MESSAGE, number=2, message="QuotaStatus",)
-
     concurrent_requests = proto.Field(proto.MESSAGE, number=3, message="QuotaStatus",)
-
     server_errors_per_project_per_hour = proto.Field(
         proto.MESSAGE, number=4, message="QuotaStatus",
     )
+    potentially_thresholded_requests_per_hour = proto.Field(
+        proto.MESSAGE, number=5, message="QuotaStatus",
+    )
 
 
 class QuotaStatus(proto.Message):
     r"""Current state for a particular quota group.
-
     Attributes:
         consumed (int):
             Quota consumed by this request.
@@ -978,14 +967,12 @@ class QuotaStatus(proto.Message):
             Quota remaining after this request.
     """
 
-    consumed = proto.Field(proto.INT32, number=1)
-
-    remaining = proto.Field(proto.INT32, number=2)
+    consumed = proto.Field(proto.INT32, number=1,)
+    remaining = proto.Field(proto.INT32, number=2,)
 
 
 class DimensionMetadata(proto.Message):
     r"""Explains a dimension.
-
     Attributes:
         api_name (str):
             This dimension's name. Useable in
@@ -1008,20 +995,15 @@ class DimensionMetadata(proto.Message):
             for this property.
     """
 
-    api_name = proto.Field(proto.STRING, number=1)
-
-    ui_name = proto.Field(proto.STRING, number=2)
-
-    description = proto.Field(proto.STRING, number=3)
-
-    deprecated_api_names = proto.RepeatedField(proto.STRING, number=4)
-
-    custom_definition = proto.Field(proto.BOOL, number=5)
+    api_name = proto.Field(proto.STRING, number=1,)
+    ui_name = proto.Field(proto.STRING, number=2,)
+    description = proto.Field(proto.STRING, number=3,)
+    deprecated_api_names = proto.RepeatedField(proto.STRING, number=4,)
+    custom_definition = proto.Field(proto.BOOL, number=5,)
 
 
 class MetricMetadata(proto.Message):
     r"""Explains a metric.
-
     Attributes:
         api_name (str):
             A metric name. Useable in `Metric <#Metric>`__'s ``name``.
@@ -1050,19 +1032,13 @@ class MetricMetadata(proto.Message):
             this property.
     """
 
-    api_name = proto.Field(proto.STRING, number=1)
-
-    ui_name = proto.Field(proto.STRING, number=2)
-
-    description = proto.Field(proto.STRING, number=3)
-
-    deprecated_api_names = proto.RepeatedField(proto.STRING, number=4)
-
+    api_name = proto.Field(proto.STRING, number=1,)
+    ui_name = proto.Field(proto.STRING, number=2,)
+    description = proto.Field(proto.STRING, number=3,)
+    deprecated_api_names = proto.RepeatedField(proto.STRING, number=4,)
     type_ = proto.Field(proto.ENUM, number=5, enum="MetricType",)
-
-    expression = proto.Field(proto.STRING, number=6)
-
-    custom_definition = proto.Field(proto.BOOL, number=7)
+    expression = proto.Field(proto.STRING, number=6,)
+    custom_definition = proto.Field(proto.BOOL, number=7,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
